OffsetSizeBytes

Enum OffsetSizeBytes 

pub(crate) enum OffsetSizeBytes {
    One = 1,
    Two = 2,
    Three = 3,
    Four = 4,
}
Used to unpack offset array entries such as metadata dictionary offsets or object/array value offsets. Also used to unpack object field ids. These are always derived from a two-bit XXX_size_minus_one field in the corresponding header byte.

Variants



One = 1



Two = 2



Three = 3



Four = 4

Implementations

Source

impl OffsetSizeBytes

pub(crate) fn try_new(offset_size_minus_one: u8) -> Result<Self, ArrowError>

Build from the offset_size_minus_one bits (see spec).

pub(crate) fn unpack_u32( &self, bytes: &[u8], index: usize, ) -> Result<u32, ArrowError>

Return one unsigned little-endian value from bytes.

  • bytes – the byte buffer to index
  • index – 0-based index into the buffer

Each value is self as u32 bytes wide (1, 2, 3 or 4), zero-extended to 32 bits as needed.

pub(crate) fn unpack_u32_at_offset( &self, bytes: &[u8], byte_offset: usize, offset_index: usize, ) -> Result<u32, ArrowError>

Return one unsigned little-endian value from bytes.

  • bytes – the byte buffer to index
  • byte_offset – number of bytes to skip before reading the first value (e.g. 1 to move past a header byte).
  • offset_index – 0-based index after the skipped bytes (0 is the first value, 1 the next, …).

Each value is self as u32 bytes wide (1, 2, 3 or 4), zero-extended to 32 bits as needed.