pub enum VariantPathElement<'a> {
Field {
name: Cow<'a, str>,
},
Index {
index: usize,
},
ListElement,
}Expand description
Element of a VariantPath that can be a field name, an index, or a list element wildcard.
See VariantPath for more details and examples.
Variants
Field
Access field with name name
Index
Access the list element at index
ListElement
Match the shared element schema of a list ([*])
Implementations
Sourceimpl<'a> VariantPathElement<'a>
impl<'a> VariantPathElement<'a>
pub fn field(name: impl Into<Cow<'a, str>>) -> VariantPathElement<'a>
pub fn index(index: usize) -> VariantPathElement<'a>
pub fn list_element() -> VariantPathElement<'a>